@@ -70,7 +70,6 @@ knh_bool_t knh_String_endsWith(String *b, knh_bytes_t s)
 
 /* ------------------------------------------------------------------------ */
 
-static
 knh_index_t knh_bytes_indexOf(knh_bytes_t base, knh_bytes_t delim)
 {
 	size_t i, j;
@@ -181,11 +180,11 @@ METHOD knh__String_opSub(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 
 INLINE static
-int knh_bytes_equals_(knh_bytes_t base, size_t s, knh_bytes_t os)
+int knh_bytes_equals_(knh_bytes_t base, size_t s, knh_bytes_t target)
 {
 	size_t i;
-	for(i = 1; i < os.len; i++) {
-		if(base.buf[s+i] != os.buf[i]) return 0;
+	for(i = 1; i < target.len; i++) {
+		if(base.buf[s+i] != target.buf[i]) return 0;
 	}
 	return 1;
 }
@@ -197,26 +196,27 @@ int knh_bytes_equals_(knh_bytes_t base, size_t s, knh_bytes_t os)
 METHOD knh__String_replace(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_bytes_t base = knh_String_tobytes(sfp[0].s);
-	knh_bytes_t os = knh_String_tobytes(sfp[1].s);
-	knh_bytes_t ns = knh_String_tobytes(sfp[2].s);
+	knh_bytes_t target = knh_String_tobytes(sfp[1].s);
+	knh_bytes_t alt = knh_String_tobytes(sfp[2].s);
 
 	knh_wbuf_t wbuf = knh_Context_wbuf(ctx);
 
 	size_t i;
-	int s = 0, ch = os.buf[0];
-	for(i = 0; i < base.len - os.len+1; i++) {
-		if(base.buf[i] == ch && knh_bytes_equals_(base, i, os)) {
-			knh_bytes_t hs = {base.buf + s, i - s};
-			knh_Bytes_write(ctx, wbuf.ba, hs);
-			knh_Bytes_write(ctx, wbuf.ba, ns);
-			i += os.len; s = i;
+	int s = 0, ch = target.buf[0];
+	for(i = 0; i < base.len - target.len+1; i++) {
+		if(base.buf[i] == ch && knh_bytes_equals_(base, i, target)) {
+			knh_Bytes_write(ctx, wbuf.ba, alt);
+			i += target.len - 1;
+			s = i;
+		}else {
+			knh_Bytes_putc(ctx, wbuf.ba, base.buf[i]);
 		}
 	}
 	if(s == 0) {
 		KNH_RETURN(ctx, sfp, sfp[0].o);
 	}
 	else {
-		knh_bytes_t hs = {base.buf + s, base.len - s};
+		knh_bytes_t hs = {base.buf + i, base.len - i};
 		knh_Bytes_write(ctx, wbuf.ba, hs);
 		KNH_RETURN(ctx, sfp, new_String__wbuf(ctx, wbuf));
 	}
