@@ -1013,6 +1013,7 @@ void knh_Token_add_space(Ctx *ctx, knh_tokenctx_t *tkctx, knh_wbuf_t tbuf, Input
 			if(SP(tkp)->tt == TT_TYPEN) {
 				if(t.buf[0] == '.' && t.buf[1] == '.' && t.buf[2] == '\0') {
 					knh_Token_setIteratorType(tkp, 1);
+					knh_Token_setNotNullType(tkp, 1);
 					knh_wbuf_clear(tbuf);
 					return;
 				}
@@ -1022,7 +1023,13 @@ void knh_Token_add_space(Ctx *ctx, knh_tokenctx_t *tkctx, knh_wbuf_t tbuf, Input
 					return;
 				}
 				if(t.buf[0] == '!' && t.buf[2] == '\0') {
-					knh_Token_setNotNullType(tkp, 1);
+					if(knh_Token_isNotNullType(tkp)) {
+						knh_Token_setNotNullType(tkp, 0);
+						knh_Token_setExceptionType(tkp, 1);
+					}
+					else {
+						knh_Token_setNotNullType(tkp, 1);
+					}
 					knh_wbuf_clear(tbuf);
 					return;
 				}
