@@ -59,11 +59,12 @@ extern "C" {
 #define KNH_OBJECT_FIELDSIZE 64
 #endif
 
-typedef knh_Object_t* (*knh_fparser)(Ctx *, knh_class_t cid, knh_bytes_t p);
+typedef knh_Object_t* (*knh_fparser)(Ctx *, struct knh_String_t *p);
 
 typedef struct {
-	int  type;
+	int   type;
 	char *name;
+	knh_type_t  rtype;
 	knh_fparser parser;
 } knh_parser_drvapi_t;
 
@@ -526,18 +527,18 @@ typedef knh_ClassSpec_t* (*f_makespec)(Ctx *ctx, knh_class_t bcid, char *extra);
 /* @flag IntUnit.Unsigned UF DP((IntUnit*)%s)->spec.flag 'is:*:is:*' */
 
 struct  knh_IntUnit_t;
-typedef knh_bool_t  (*f_iunit_chk)(struct knh_IntUnit_t *, knh_int_t v);
-typedef knh_int_t   (*f_iunit_cmp)(struct knh_IntUnit_t *, knh_int_t v1, knh_int_t v2);
-typedef void        (*f_iunit_fmt)(struct knh_IntUnit_t *, char *buf, size_t bufsiz, knh_int_t v);
+typedef knh_bool_t (*f_iunit_chk)(struct knh_IntUnit_t *, knh_integer_t v);
+typedef int (*f_iunit_cmp)(struct knh_IntUnit_t *, knh_integer_t v1, knh_integer_t v2);
+typedef void (*f_iunit_fmt)(struct knh_IntUnit_t *, char *buf, size_t bufsiz, knh_integer_t v);
 
 typedef struct knh_IntUnit {
 	knh_hClassSpec_struct spec;
 	f_iunit_chk fchk;
 	f_iunit_cmp fcmp;
 	f_iunit_fmt ffmt;
-	knh_int_t min;
-	knh_int_t max;
-	knh_int_t step;
+	knh_integer_t min;
+	knh_integer_t max;
+	knh_integer_t step;
 	knh_int_t bfoffset;
 	size_t bfsize;
 	knh_Int_t** bfarray;
@@ -547,9 +548,9 @@ typedef struct knh_IntUnit {
 /* @class FloatUnit Object knh_FloatUnit_struct @Private */
 
 struct knh_FloatUnit_t;
-typedef knh_bool_t  (*f_funit_chk)(struct knh_FloatUnit_t *, knh_float_t v);
-typedef knh_int_t   (*f_funit_cmp)(struct knh_FloatUnit_t *, knh_float_t v1, knh_float_t v2);
-typedef void       (*f_funit_fmt)(struct knh_FloatUnit_t *, char *buf, size_t bufsiz, knh_float_t v);
+typedef knh_bool_t (*f_funit_chk)(struct knh_FloatUnit_t *, knh_float_t v);
+typedef int (*f_funit_cmp)(struct knh_FloatUnit_t *, knh_float_t v1, knh_float_t v2);
+typedef void (*f_funit_fmt)(struct knh_FloatUnit_t *, char *buf, size_t bufsiz, knh_float_t v);
 
 typedef struct knh_FloatUnit {
 	knh_hClassSpec_struct spec;
@@ -801,6 +802,17 @@ typedef struct knh_ResultSet {
 /* @flag Exception.Generated EF DP((Exception*)%s)->flag 'is:*:is:*' */
 /* @flag Exception.Caught EF DP((Exception*)%s)->flag 'is:set:*:*' */
 
+/* @expt Exception!! - */
+/* @expt Fatal!! - */
+/* @expt OutOfMemory!! Fatal!! */
+/* @expt Security!! - */
+/* @expt Null!! - */
+/* @expt OutOfIndex!! - */
+/* @expt IO!! - */
+/* @expt Script!! - */
+/* @expt Syntax!! Script!! */
+/* @expt Type!! Script!! */
+
 typedef struct knh_Exception {
 	knh_flag_t flag;
 	knh_expt_t eid;
@@ -833,8 +845,21 @@ typedef struct knh_Script_t {
 /* ------------------------------------------------------------------------ */
 /* @class NameSpace Object knh_NameSpace_struct @Private */
 
-typedef int (*f_libknh_init)(Ctx *ctx);
-typedef void (*f_libknh_traverse)(Ctx *ctx, f_traverse ftr);
+typedef int (*f_pkginit)(Ctx *ctx);
+typedef void (*f_pkgtraverse)(Ctx *ctx, f_traverse ftr);
+
+typedef struct knh_pkgmeta_t {
+	const int buildid;
+	const char *name;  /* "unix" */
+	const char *version; /* "version" */
+	const char *desc;
+	const char *url;
+	f_pkginit finit;
+	f_pkgtraverse ftraverse;
+	const char *script;
+} knh_pkgmeta_t;
+
+typedef knh_pkgmeta_t* (*f_pkgload)(Ctx *ctx);
 
 typedef struct knh_NameSpace {
 	struct knh_NameSpace_t* parent;
@@ -846,7 +871,7 @@ typedef struct knh_NameSpace {
 	struct knh_DictMap_t*   tag2urnDictMap;
 	struct knh_Script_t*    script;
 	void                   *dlhdr;
-	f_libknh_traverse       ftraverse;
+	knh_pkgmeta_t          *pkgmeta;
 } knh_NameSpace_struct;
 
 /* ------------------------------------------------------------------------ */
@@ -886,8 +911,8 @@ typedef struct knh_Runtime {
 /* ------------------------------------------------------------------------ */
 /* @class Context Object knh_Context_t */
 /* @flag Context.Release!Debug CTXF ((Context*)%s)->flag 'is:set:is:set' */
-/* @flag Context.Root CTXF ((Context*)%s)->flag 'is:set:*:*' */
-/* @flag Context.Evaluating CTXF ((Context*)%s)->flag 'is:set:*:*' */
+/* @flag Context.Admin CTXF ((Context*)%s)->flag 'is:set:*:*' */
+/* @flag Context.Strict CTXF ((Context*)%s)->flag 'is:set:*:*' */
 /* @flag Context.Compiling CTXF ((Context*)%s)->flag 'is:set:*:*' */
 /* @flag Context.Verbose CTXF ((Context*)%s)->flag 'is:set:is:set' */
 /* @flag Context.Verbose2 CTXF ((Context*)%s)->flag 'is:set:is:set' */
