@@ -54,22 +54,16 @@ extern "C" {
 #define knh_Bytes_value(o)     (o)->buf
 #define knh_Bytes_last(o)      ((o)->buf + (o)->size)
 #define knh_Bytes_tochar(b)  (char*)knh_Bytes_value(b)
-#define knh_BytesConv_struct_copy NULL
-#define knh_BytesConv_struct_compare NULL
 #define KNH_SIZE(v)         knh_size(v)
 #define B(c)     new_bytes(c)
 #define B2(c,n)   new_bytes__2(c,n)
 #define STEXT(c)  new_bytes__2(c,sizeof(c)-1)
 #define ISB(t,c) (t.len == (sizeof(c)-1) && knh_strncmp((char*)t.buf,c,t.len) == 0)
+#define knh_BytesConv_struct_copy NULL
+#define knh_BytesConv_struct_compare NULL
 #define CLASS_newid          ((knh_class_t)-1)
 #define CLASS_unknown        ((knh_class_t)-2)
 #define knh_Class_cid(c)     (knh_class_t)(c)->cid
-#define knh_ClassMap_struct_copy    NULL
-#define knh_ClassMap_struct_compare  NULL
-#define knh_tstruct_isNative(sid)   (sid < KONOHA_TSTRUCT_SIZE)
-#define knh_ClassStruct_struct_copy    NULL
-#define knh_Class_getMethod(ctx, c, mn)    knh_Class_getMethod__(ctx, c, mn, 0)
-#define knh_Class_findMethod(ctx, c, mn)   knh_Class_getMethod__(ctx, c, mn, 1)
 #define IS_SPEC(o)   (CLASS_IntUnit <= knh_Object_cid(o)  && knh_Object_cid(o) <= CLASS_Vocabulary)
 #define KNH_FLAG_TF_NN                KNH_FLAG_T0
 #define TYPE_ISNULLABLE(t)            ((t & KNH_FLAG_TF_NN)==0)
@@ -84,6 +78,12 @@ extern "C" {
 #define TYPE_any                      CLASS_Any
 #define NNTYPE_any                    CLASS_any
 #define TYPEN(type)  knh_TYPEN(ctx,type)
+#define knh_ClassMap_struct_copy    NULL
+#define knh_ClassMap_struct_compare  NULL
+#define knh_tstruct_isNative(sid)   (sid < KONOHA_TSTRUCT_SIZE)
+#define knh_ClassStruct_struct_copy    NULL
+#define knh_Class_getMethod(ctx, c, mn)    knh_Class_getMethod__(ctx, c, mn, 0)
+#define knh_Class_findMethod(ctx, c, mn)   knh_Class_getMethod__(ctx, c, mn, 1)
 #define knh_Connection_struct_copy    NULL
 #define knh_Connection_struct_compare  NULL
 #define KNH_STDIN          (((Context*)ctx)->in)
@@ -181,6 +181,8 @@ extern "C" {
 #define DEBUG_ASSERT_cid(cid)    KNH_ASSERT(IS_cid(cid))
 #define CLASSN(cid)   knh_String_tochar(knh_tClass[cid].lname)
 #define CLASSNo(o)    knh_String_tochar(knh_tClass[(o)->h.cid].lname)
+#define EXPT_unknown  ((knh_expt_t)-1)
+#define EXPT_newid    ((knh_expt_t)0)
 #define DEBUG_ASSERT_eid(cid)    KNH_ASSERT(IS_eid(cid))
 #define EXPTN(eid)   knh_String_tochar(knh_tExpt_name(eid))
 #define KNH_TMAPMAP  KNH_TMAPPER
@@ -274,7 +276,15 @@ extern "C" {
 /* ======================================================================== */
 /* [PROTOTYPE] */
 KNHAPI(void) konoha_addAffineMapper(Ctx *ctx, knh_class_t scid, char *text, knh_float_t scale, knh_float_t shift);
+KNHAPI(Bytes*) new_Bytes(Ctx *ctx, size_t capacity);
+KNHAPI(knh_bytes_t) knh_Bytes_tobytes(Bytes *o);
+KNHAPI(void) knh_Bytes_clear(Bytes *o);
+KNHAPI(void) knh_Bytes_putc(Ctx *ctx, Bytes *o, int ch);
+KNHAPI(void) knh_Bytes_write(Ctx *ctx, Bytes *o, knh_bytes_t v);
 KNHAPI(void) konoha_addDataBaseDriver(Ctx *ctx, char *alias, knh_db_drvapi_t *d);
+KNHAPI(Exception*) new_Exception(Ctx *ctx, String *msg);
+KNHAPI(Exception*) new_Exception__b(Ctx *ctx, knh_bytes_t msg);
+KNHAPI(Exception*) new_Exception__errno(Ctx *ctx);
 KNHAPI(ClassSpec*) new_Unit(Ctx *ctx, char *tag, knh_float_t min, knh_float_t max, knh_float_t defv, knh_float_t step);
 KNHAPI(void) konoha_addInputStreamDriver(Ctx *ctx, char *alias, knh_inptr_drvapi_t *d);
 KNHAPI(void) konoha_addOutputStreamDriver(Ctx *ctx, char *alias, knh_outptr_drvapi_t *d);
@@ -297,9 +307,16 @@ KNHAPI(void) knh_ResultSet_setFloat(Ctx *ctx, ResultSet *o, size_t n, knh_float_
 KNHAPI(void) knh_ResultSet_setBytes(Ctx *ctx, ResultSet *o, size_t n, knh_bytes_t t);
 KNHAPI(void) knh_ResultSet_setNULL(Ctx *ctx, ResultSet *o, size_t n);
 KNHAPI(void) konoha_addAliasURN(Ctx *ctx, char *alias, char *urn);
+KNHAPI(String*) new_String_bconv(Ctx *ctx, String *s, f_bconv bconv);
+KNHAPI(void) konoha_addParserDriver(Ctx *ctx, char *alias, knh_parser_drvapi_t *d);
 KNHAPI(ClassSpec*) new_Vocabulary(Ctx *ctx, char *lang, char *defval, ...);
 KNHAPI(void) konoha_addVocabularyMapper(Ctx *ctx, knh_class_t scid, char *text);
-KNHAPI(String*) new_String_bconv(Ctx *ctx, String *s, f_bconv bconv);
+KNHAPI(size_t) knh_stat_usedMemorySize(void);
+KNHAPI(f_traverse) konoha_sweep();
+KNHAPI(int) konoha_issweep(f_traverse ftr);
+KNHAPI(Int*) new_Int__fast(Ctx *ctx, knh_class_t cid, knh_integer_t value);
+KNHAPI(Float*) new_Float__fast(Ctx *ctx, knh_class_t cid, knh_float_t value);
+KNHAPI(void) konoha_addClassSpecFunc(Ctx *ctx, char *urn, f_makespec func);
 KNHAPI(konoha_t) konoha_open(void);
 KNHAPI(void) konoha_close(konoha_t konoha);
 KNHAPI(Ctx*) konoha_open_context(konoha_t konoha);
@@ -315,15 +332,8 @@ KNHAPI(void) konoha_addIntConst(Ctx *ctx, char *name, knh_int_t value);
 KNHAPI(void) konoha_addFloatConst(Ctx *ctx, char *name, knh_float_t value);
 KNHAPI(void) konoha_addStringConst(Ctx *ctx, char *name, char *text);
 KNHAPI(void) konoha_addDriver(Ctx *ctx, char *name, int type, void *drv);
-KNHAPI(void) konoha_shell(Ctx *ctx);
-KNHAPI(size_t) knh_stat_usedMemorySize(void);
-KNHAPI(f_traverse) konoha_sweep();
-KNHAPI(int) konoha_issweep(f_traverse ftr);
-KNHAPI(Int*) new_Int__fast(Ctx *ctx, knh_class_t cid, knh_integer_t value);
-KNHAPI(Float*) new_Float__fast(Ctx *ctx, knh_class_t cid, knh_float_t value);
-KNHAPI(void) konoha_addParserDriver(Ctx *ctx, char *alias, knh_parser_drvapi_t *d);
-KNHAPI(void) konoha_addClassSpecFunc(Ctx *ctx, char *urn, f_makespec func);
 KNHAPI(char*) KNH_SAFEFILE(char *file);
+KNHAPI(void) konoha_shell(Ctx *ctx);
 KNHAPI(void) knh_throw_TODO(Ctx *ctx, char *file, int line, char *func);
 KNHAPI(void) knh_throwException(Ctx *ctx, Exception *e);
 KNHAPI(void) knh_throw(Ctx *ctx, Object *e);
