@@ -115,25 +115,9 @@ String* knh_Boolean_String(Ctx *ctx, Boolean *o, Mapper *mpr);
 Boolean* knh_String_Boolean(Ctx *ctx, String *o, Mapper *mpr);
 void knh_Boolean__s(Ctx *ctx, Boolean *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_Bytes.c */
-Bytes* new_Bytes(Ctx *ctx, size_t capacity);
-knh_bytes_t knh_Bytes_tobytes(Bytes *o);
 knh_bytes_t knh_BytesNULL_tobytes(Bytes *o);
 char *knh_BytesNULL_tochar(Bytes *o);
-void knh_Bytes_clear(Bytes *o);
-void knh_Bytes_putc(Ctx *ctx, Bytes *o, int ch);
-void knh_Bytes_write(Ctx *ctx, Bytes *o, knh_bytes_t v);
 void knh_Bytes_unputc(Bytes *o);
-/* ../class/konoha/knh_BytesConv.c */
-void knh_BytesConv_struct_init(Ctx *ctx, knh_BytesConv_struct *b, int init, Object *cs);
-void knh_BytesConv_struct_traverse(Ctx *ctx, knh_BytesConv_struct *b, f_traverse ftr);
-size_t knh_BytesConv_conv(Ctx *ctx, BytesConv *o, knh_bytes_t t, knh_Bytes_t *ba);
-BytesConv* new_BytesConv(Ctx *ctx, String *name, f_bconv fbconv);
-BytesConv* new_BytesConv__iconv(Ctx *ctx, char *from, char *to);
-BytesConv* new_BytesConv__in(Ctx *ctx, char *from);
-BytesConv* new_BytesConv__out(Ctx *ctx, char *to);
-String *new_String__bconv(Ctx *ctx, knh_bytes_t t, BytesConv *bconv);
-String *new_String__wbufconv(Ctx *ctx, knh_wbuf_t cb, BytesConv *bconv);
-void knh_BytesConv__k(Ctx *ctx, BytesConv *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_Bytes_api1.c */
 METHOD knh__Bytes_new(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Bytes_putc(Ctx *ctx, knh_sfp_t *sfp);
@@ -167,11 +151,36 @@ knh_bytes_t knh_bytes_trim(knh_bytes_t t, knh_int_t ch);
 knh_int_t knh_bytes_toint(knh_bytes_t t);
 knh_float_t knh_bytes_tofloat(knh_bytes_t t);
 knh_int64_t knh_bytes_toint64(knh_bytes_t t);
+/* ../class/konoha/knh_BytesConv.c */
+void knh_BytesConv_struct_init(Ctx *ctx, knh_BytesConv_struct *b, int init, Object *cs);
+void knh_BytesConv_struct_traverse(Ctx *ctx, knh_BytesConv_struct *b, f_traverse ftr);
+size_t knh_BytesConv_conv(Ctx *ctx, BytesConv *o, knh_bytes_t t, knh_Bytes_t *ba);
+BytesConv* new_BytesConv(Ctx *ctx, String *name, f_bconv fbconv);
+BytesConv* new_BytesConv__iconv(Ctx *ctx, char *from, char *to);
+BytesConv* new_BytesConv__in(Ctx *ctx, char *from);
+BytesConv* new_BytesConv__out(Ctx *ctx, char *to);
+String *new_String__bconv(Ctx *ctx, knh_bytes_t t, BytesConv *bconv);
+String *new_String__wbufconv(Ctx *ctx, knh_wbuf_t cb, BytesConv *bconv);
+void knh_BytesConv__k(Ctx *ctx, BytesConv *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_Class.c */
 knh_Class_t *new_Class__type(Ctx *ctx, knh_type_t type);
 Object *knh_Class_fdefault(Ctx *ctx, knh_class_t cid);
 knh_hcode_t knh_Class_hashCode(Class *o);
 int knh_Class_compareTo(Class *o, Class *o2);
+/* ../class/konoha/knh_Class_api1.c */
+void knh_Class__s(Ctx *ctx, Class *o, OutputStream *w, String *m);
+void knh_Class__k(Ctx *ctx, Class *o, OutputStream *w, String *m);
+void knh_Class__dump(Ctx *ctx, Class *o, OutputStream *w, String *m);
+void knh_Class__man(Ctx *ctx, Class *o, OutputStream *w, String *m);
+/* ../class/konoha/knh_Class_type_t.c */
+knh_class_t knh_pmztype_toclass(Ctx *ctx, knh_type_t t, knh_class_t this_cid);
+knh_type_t knh_pmztype_totype(Ctx *ctx, knh_type_t t, knh_class_t this_cid);
+knh_class_t knh_class_Array(Ctx *ctx, knh_class_t p1);
+knh_class_t knh_class_Iterator(Ctx *ctx, knh_class_t p1);
+knh_class_t knh_pmzclass(Ctx *ctx, knh_class_t bcid, knh_class_t p1, knh_class_t p2);
+knh_bool_t knh_bytes_isNotNullType(knh_bytes_t t);
+char *TYPEQ(knh_type_t type);
+char *knh_TYPEN(Ctx *ctx, knh_type_t type);
 /* ../class/konoha/knh_ClassMap.c */
 void knh_ClassMap_struct_init(Ctx *ctx, knh_ClassMap_struct *b, int init, Object *cs);
 void knh_ClassMap_struct_traverse(Ctx *ctx, knh_ClassMap_struct *b, f_traverse gc);
@@ -193,20 +202,6 @@ void knh_Class_addMethod__fast(Ctx *ctx, knh_class_t cid, Method *mtd);
 void knh_Class_addMethod(Ctx *ctx, knh_class_t cid, Method *mtd);
 Method* knh_Class_getMethod__(Ctx *ctx, knh_class_t this_cid, knh_methodn_t mn, knh_bool_t gen);
 void knh_cfield_dump(Ctx *ctx, knh_cfield_t *f, size_t offset, size_t fsize, OutputStream *w);
-/* ../class/konoha/knh_Class_api1.c */
-void knh_Class__s(Ctx *ctx, Class *o, OutputStream *w, String *m);
-void knh_Class__k(Ctx *ctx, Class *o, OutputStream *w, String *m);
-void knh_Class__dump(Ctx *ctx, Class *o, OutputStream *w, String *m);
-void knh_Class__man(Ctx *ctx, Class *o, OutputStream *w, String *m);
-/* ../class/konoha/knh_Class_type_t.c */
-knh_class_t knh_pmztype_toclass(Ctx *ctx, knh_type_t t, knh_class_t this_cid);
-knh_type_t knh_pmztype_totype(Ctx *ctx, knh_type_t t, knh_class_t this_cid);
-knh_class_t knh_class_Array(Ctx *ctx, knh_class_t p1);
-knh_class_t knh_class_Iterator(Ctx *ctx, knh_class_t p1);
-knh_class_t knh_pmzclass(Ctx *ctx, knh_class_t bcid, knh_class_t p1, knh_class_t p2);
-knh_bool_t knh_bytes_isNotNullType(knh_bytes_t t);
-char *TYPEQ(knh_type_t type);
-char *knh_TYPEN(Ctx *ctx, knh_type_t type);
 /* ../class/konoha/knh_Connection.c */
 knh_db_drvapi_t * knh_System_getDataBaseDriver(Ctx *ctx, knh_bytes_t name);
 void knh_Connection_struct_init(Ctx *ctx, knh_Connection_struct *b, int init, Object *cs);
@@ -257,6 +252,25 @@ String* knh_DictIdx_get__fast(DictIdx *o, knh_int_t termid);
 String* knh_DictIdx_get(DictIdx *o, knh_int_t termid);
 void knh_DictIdx_clear(Ctx *ctx, DictIdx *o);
 void knh_DictIdx__k(Ctx *ctx, DictIdx *o, OutputStream *w, String *m);
+/* ../class/konoha/knh_DictMap_api1.c */
+METHOD knh__DictMap_new(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_new__init(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_get(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_opHas(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_set(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_remove(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_clear(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_getSize(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_subset(Ctx *ctx, knh_sfp_t *sfp, int mode);
+METHOD knh__DictMap_opSubsete(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_opSubset(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_opOffset(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__DictMap_opLshift(Ctx *ctx, knh_sfp_t *sfp);
+Object *knh_DictMap_key_next(Ctx *ctx, Iterator *it);
+Iterator* knh_DictMap_Iterator(Ctx *ctx, DictMap *o, Mapper *mpr);
+Iterator* knh_DictMap_String__(Ctx *ctx, DictMap *o, Mapper *mpr);
+METHOD knh__DictMap_opItr(Ctx *ctx, knh_sfp_t *sfp);
+void knh_DictMap__k(Ctx *ctx, DictMap *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_DictMapSet.c */
 knh_dict_t* knh_dict_resize(Ctx *ctx, knh_dict_t *a, size_t newsize);
 void knh_dict_traverse(Ctx *ctx, knh_dict_t *a, f_traverse ftr);
@@ -291,25 +305,6 @@ void knh_DictSet_set(Ctx *ctx, DictSet *o, String *key, knh_uint_t n);
 void knh_DictSet_add(Ctx *ctx, DictSet *o, String *key);
 void knh_DictSet_remove(Ctx *ctx, DictSet *o, String *key);
 void knh_DictSet_clear(Ctx *ctx, DictSet *o);
-/* ../class/konoha/knh_DictMap_api1.c */
-METHOD knh__DictMap_new(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_new__init(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_get(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_opHas(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_set(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_remove(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_clear(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_getSize(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_subset(Ctx *ctx, knh_sfp_t *sfp, int mode);
-METHOD knh__DictMap_opSubsete(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_opSubset(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_opOffset(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_opLshift(Ctx *ctx, knh_sfp_t *sfp);
-Object *knh_DictMap_key_next(Ctx *ctx, Iterator *it);
-Iterator* knh_DictMap_Iterator(Ctx *ctx, DictMap *o, Mapper *mpr);
-Iterator* knh_DictMap_String__(Ctx *ctx, DictMap *o, Mapper *mpr);
-METHOD knh__DictMap_opItr(Ctx *ctx, knh_sfp_t *sfp);
-void knh_DictMap__k(Ctx *ctx, DictMap *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_DictSet_api1.c */
 METHOD knh__DictSet_new(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__DictSet_add(Ctx *ctx, knh_sfp_t *sfp);
@@ -333,9 +328,15 @@ void knh_DictSet__dump(Ctx *ctx, DictSet *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_Exception.c */
 void knh_Exception_struct_init(Ctx *ctx, knh_Exception_struct *b, int init, Object *cs);
 void knh_Exception_struct_traverse(Ctx *ctx, knh_Exception_struct *b, f_traverse gc);
-Exception* new_Exception(Ctx *ctx, String *msg);
-Exception* new_Exception__b(Ctx *ctx, knh_bytes_t msg);
+Exception* knh_Exception_new__init(Ctx *ctx, Exception *o, String *e, String *msg, Object *bag);
 Exception* new_Exception__Nue(Ctx *ctx, knh_Nue_t *nue);
+/* ../class/konoha/knh_Exception_api1.c */
+METHOD knh__Exception_new(Ctx *ctx, knh_sfp_t *sfp);
+int knh_Exception_isa(Ctx *ctx, Exception *o, String *msg);
+METHOD knh__Exception_opIsa(Ctx *ctx, knh_sfp_t *sfp);
+void knh_Exception__s(Ctx *ctx, Exception *o, OutputStream *w, String *m);
+void knh_Exception__k(Ctx *ctx, Exception *o, OutputStream *w, String *m);
+void knh_Exception__dump(Ctx *ctx, Exception *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_ExceptionHandler.c */
 void knh_ExceptionHandler_struct_init(Ctx *ctx, knh_ExceptionHandler_struct *b, int init, Object *cs);
 void knh_ExceptionHandler_struct_traverse(Ctx *ctx, knh_ExceptionHandler_struct *b, f_traverse gc);
@@ -343,9 +344,6 @@ ExceptionHandler* new_ExceptionHandler(Ctx *ctx);
 Object *knh_ExceptionHandler_fdefault(Ctx *ctx, knh_class_t cid);
 void knh_ExceptionHandler_longjmp(Ctx *ctx, ExceptionHandler *b, Exception *e);
 Exception* knh_ExceptionHandler_getCaughtException(ExceptionHandler *b);
-/* ../class/konoha/knh_Exception_api1.c */
-void knh_Exception__s(Ctx *ctx, Exception *b, OutputStream *w, String *m);
-void knh_Exception__dump(Ctx *ctx, Exception *b, OutputStream *w, String *m);
 /* ../class/konoha/knh_Float.c */
 Float* new_FloatX0(Ctx *ctx, knh_class_t cid, knh_float_t value);
 Float* new_FloatX(Ctx *ctx, knh_class_t cid, knh_float_t value);
@@ -356,13 +354,6 @@ int knh_Float_compareTo(Float *o, Float *o2);
 char *knh_format_Float(char *buf, size_t bufsiz, Float *o);
 knh_float_t knh_float_max(knh_float_t a, knh_float_t b);
 knh_float_t knh_float_min(knh_float_t a, knh_float_t b);
-/* ../class/konoha/knh_FloatUnit.c */
-void knh_FloatUnit_struct_init(Ctx *ctx, knh_FloatUnit_struct *b, int init, Object *cs);
-void knh_FloatUnit_struct_traverse(Ctx *ctx, knh_FloatUnit_struct *b, f_traverse gc);
-FloatUnit *new_FloatUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *tag, knh_float_t min, knh_float_t max, knh_float_t defvalue, knh_float_t step);
-void knh_FloatUnit_initStep(Ctx *ctx, FloatUnit *b, knh_float_t step);
-void knh_FloatUnit_initMinMax(Ctx *ctx, FloatUnit *b, knh_float_t min, knh_float_t max);
-void knh_FloatUnit_initDefaultValue(Ctx *ctx, FloatUnit *b, knh_float_t v);
 /* ../class/konoha/knh_Float_api1.c */
 METHOD knh__Float_opAdd(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Float_opNeg(Ctx *ctx, knh_sfp_t *sfp);
@@ -389,6 +380,13 @@ void knh_Float__f(Ctx *ctx, Float *o, OutputStream *w, String *m);
 void knh_Float__k(Ctx *ctx, Float *o, OutputStream *w, String *m);
 void knh_Float__bits(Ctx *ctx, Float *o, OutputStream *w, String *m);
 void knh_Float__dump(Ctx *ctx, Float *o, OutputStream *w, String *m);
+/* ../class/konoha/knh_FloatUnit.c */
+void knh_FloatUnit_struct_init(Ctx *ctx, knh_FloatUnit_struct *b, int init, Object *cs);
+void knh_FloatUnit_struct_traverse(Ctx *ctx, knh_FloatUnit_struct *b, f_traverse gc);
+FloatUnit *new_FloatUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *tag, knh_float_t min, knh_float_t max, knh_float_t defvalue, knh_float_t step);
+void knh_FloatUnit_initStep(Ctx *ctx, FloatUnit *b, knh_float_t step);
+void knh_FloatUnit_initMinMax(Ctx *ctx, FloatUnit *b, knh_float_t min, knh_float_t max);
+void knh_FloatUnit_initDefaultValue(Ctx *ctx, FloatUnit *b, knh_float_t v);
 /* ../class/konoha/knh_HashMap.c */
 void knh_HashMap_struct_init(Ctx *ctx, knh_HashMap_struct *b, int init, Object *cs);
 knh_hashmapentry_t *new_hashmapentry(Ctx *ctx, HashMap *o);
@@ -451,14 +449,6 @@ knh_int_t knh_int_min(knh_int_t a, knh_int_t b);
 knh_uint_t knh_uint_max(knh_uint_t a, knh_uint_t b);
 knh_uint_t knh_uint_min(knh_uint_t a, knh_uint_t b);
 knh_integer_t knh_IntNULL_toint(Int *v);
-/* ../class/konoha/knh_IntUnit.c */
-void knh_IntUnit_struct_init(Ctx *ctx, knh_IntUnit_struct *b, int init, Object *cs);
-void knh_IntUnit_struct_traverse(Ctx *ctx, knh_IntUnit_struct *b, f_traverse gc);
-IntUnit *new_IntUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *urn, String *tag, knh_int_t min, knh_int_t max, knh_int_t defvalue, knh_int_t bf_start, knh_int_t bf_end);
-void knh_IntUnit_initId(Ctx *ctx, IntUnit *b, knh_flag_t flag, knh_class_t cid, String *urn, String *tag);
-void knh_IntUnit_initMinMax(Ctx *ctx, IntUnit *b, knh_int_t min, knh_int_t max);
-void knh_IntUnit_init_bfarray(Ctx *ctx, IntUnit *b, knh_int_t bf_start, knh_int_t bf_end);
-void knh_IntUnit_initDefaultValue(Ctx *ctx, IntUnit *b, knh_int_t v);
 /* ../class/konoha/knh_Int_api1.c */
 METHOD knh__Int_opAdd(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Int_opNeg(Ctx *ctx, knh_sfp_t *sfp);
@@ -484,12 +474,21 @@ METHOD knh__Int_getSize(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Int_random(Ctx *ctx, knh_sfp_t *sfp);
 Int* knh_String_Int(Ctx *ctx, String *o, Mapper *mpr);
 String* knh_Int_String(Ctx *ctx, Int *o, Mapper *mpr);
-void knh_Int__s(Ctx *ctx, Int *b, OutputStream *w, String *m);
+void knh_Int__s(Ctx *ctx, Int *o, OutputStream *w, String *m);
 void knh_Int__d(Ctx *ctx, Int *o, OutputStream *w, String *m);
+void knh_Int__u(Ctx *ctx, Int *o, OutputStream *w, String *m);
 void knh_Int__f(Ctx *ctx, Int *o, OutputStream *w, String *m);
-void knh_Int__x(Ctx *ctx, Int *b, OutputStream *w, String *m);
-void knh_write_bits(Ctx *ctx, OutputStream *w, knh_uint_t n, int bits);
+void knh_Int__x(Ctx *ctx, Int *o, OutputStream *w, String *m);
+void knh_write_bits(Ctx *ctx, OutputStream *w, knh_uint64_t n, int bits);
 void knh_Int__bits(Ctx *ctx, Int *b, OutputStream *w, String *m);
+/* ../class/konoha/knh_IntUnit.c */
+void knh_IntUnit_struct_init(Ctx *ctx, knh_IntUnit_struct *b, int init, Object *cs);
+void knh_IntUnit_struct_traverse(Ctx *ctx, knh_IntUnit_struct *b, f_traverse gc);
+IntUnit *new_IntUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *urn, String *tag, knh_integer_t min, knh_integer_t max, knh_integer_t defvalue, knh_int_t bf_start, knh_int_t bf_end);
+void knh_IntUnit_initId(Ctx *ctx, IntUnit *b, knh_flag_t flag, knh_class_t cid, String *urn, String *tag);
+void knh_IntUnit_initMinMax(Ctx *ctx, IntUnit *b, knh_integer_t min, knh_integer_t max);
+void knh_IntUnit_init_bfarray(Ctx *ctx, IntUnit *b, knh_int_t bf_start, knh_int_t bf_end);
+void knh_IntUnit_initDefaultValue(Ctx *ctx, IntUnit *b, knh_integer_t v);
 /* ../class/konoha/knh_Iterator.c */
 void knh_Iterator_struct_init(Ctx *ctx, knh_Iterator_struct *b, int init, Object *cs);
 void knh_Iterator_struct_copy(Ctx *ctx, knh_Iterator_struct *b, knh_Iterator_struct *b2);
@@ -656,6 +655,7 @@ void knh_write__s(Ctx *ctx, OutputStream *w, char *s);
 void knh_write__p(Ctx *ctx, OutputStream *w, void *ptr);
 void knh_write__ifmt(Ctx *ctx, OutputStream *w, char *fmt, knh_int_t n);
 void knh_write__ffmt(Ctx *ctx, OutputStream *w, char *fmt, knh_float_t n);
+void knh_write_integerfmt(Ctx *ctx, OutputStream *w, char *fmt, knh_integer_t n);
 void knh_write__flag(Ctx *ctx, OutputStream *w, knh_flag_t flag);
 void knh_write__type(Ctx *ctx, OutputStream *w, knh_type_t type);
 void knh_write__class(Ctx *ctx, OutputStream *w, knh_class_t cid);
@@ -712,15 +712,11 @@ int knh_String_compareTo(String *o, String *o2);
 char *knh_StringNULL_tochar(String *o);
 knh_bytes_t knh_String_tobytes(String *o);
 knh_bytes_t knh_StringNULL_tobytes(String *o);
-/* ../class/konoha/knh_StringUnit.c */
-void knh_StringUnit_struct_init(Ctx *ctx, knh_StringUnit_struct *b, int init, Object *cs);
-void knh_StringUnit_struct_traverse(Ctx *ctx, knh_StringUnit_struct *b, f_traverse gc);
-StringUnit *new_StringUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *tag);
-Object *knh_String_cspec(Ctx *ctx);
 /* ../class/konoha/knh_String_api1.c */
 knh_bool_t knh_String_equals(String *o, knh_bytes_t s);
 knh_bool_t knh_String_startsWith(String *b, knh_bytes_t s);
 knh_bool_t knh_String_endsWith(String *b, knh_bytes_t s);
+knh_index_t knh_bytes_indexOf(knh_bytes_t base, knh_bytes_t delim);
 METHOD knh__String_indexOf(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__String_getSize(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__String_opAdd(Ctx *ctx, knh_sfp_t *sfp);
@@ -746,6 +742,15 @@ void knh_String__k(Ctx *ctx, String *o, OutputStream *w, String *m);
 knh_bool_t knh_bytes_checkENCODING(knh_bytes_t s);
 size_t knh_bytes_mlen(knh_bytes_t s);
 knh_bytes_t knh_bytes_mofflen(knh_bytes_t m, size_t moff, size_t mlen);
+/* ../class/konoha/knh_StringParser.c */
+Object* new_String_parseOf(Ctx *ctx, String *p);
+knh_type_t	knh_ObjectParser_typing(Ctx *ctx, knh_bytes_t t);
+Object *new_Object_parseOf(Ctx *ctx, String *s);
+/* ../class/konoha/knh_StringUnit.c */
+void knh_StringUnit_struct_init(Ctx *ctx, knh_StringUnit_struct *b, int init, Object *cs);
+void knh_StringUnit_struct_traverse(Ctx *ctx, knh_StringUnit_struct *b, f_traverse gc);
+StringUnit *new_StringUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *tag);
+Object *knh_String_cspec(Ctx *ctx);
 /* ../class/konoha/knh_System.c */
 Object *knh_System_fdefault(Ctx *ctx, knh_class_t cid);
 char * knh_bytes_nzenvkey(knh_bytes_t t, char *buf, size_t bufsiz);
@@ -760,6 +765,7 @@ METHOD knh__System_setOut(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__System_getErr(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__System_setErr(Ctx *ctx, knh_sfp_t *sfp);
 void knh_System__k(Ctx *ctx, System *o, OutputStream *w, String *m);
+void knh_System__dump(Ctx *ctx, System *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_Tuple2.c */
 Tuple2 *new_Tuple2(Ctx *ctx, Object *first, Object *second);
 /* ../class/konoha/knh_Tuple2_api1.c */
@@ -868,15 +874,17 @@ Stmt *knh_Stmt_tail(Stmt *o);
 Stmt* knh_StmtNULL_tail_append(Ctx *ctx, Stmt *o, Stmt *stmt);
 void knh_Stmt__s(Ctx *ctx, Stmt *o, OutputStream *w, String *m);
 void knh_Stmt__dump(Ctx *ctx, Stmt *o, OutputStream *w, String *m);
+/* ../class/konohac/knh_Stmt_const.c */
+Term* knh_Stmt_const(Ctx *ctx, Stmt *b, knh_class_t reqc, NameSpace *ns);
 /* ../class/konohac/knh_StmtCLASS.c */
 void knh_class_addInterface(Ctx *ctx, knh_class_t cid, knh_class_t icid);
 void knh_StmtCLASS_decl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int level);
 void knh_StmtCLASS_name(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int level);
 void knh_StmtCLASS_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
 /* ../class/konohac/knh_StmtDEBUG.c */
-	 void knh_Stmt_toERR(Ctx *ctx, Stmt *stmt, String *msg);
-	 void knh_StmtERR_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
-	 void knh_StmtPRINT_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
+void knh_Stmt_toERR(Ctx *ctx, Stmt *stmt, String *msg);
+void knh_StmtERR_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
+void knh_StmtPRINT_cmpl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
 void knh_StmtASSERT_decl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, knh_type_t reqt, int level);
 /* ../class/konohac/knh_StmtDECLLET.c */
 knh_type_t knh_Compiler_typeinfer(Ctx *ctx, Compiler *cpr, knh_type_t type, char *varname);
@@ -970,8 +978,6 @@ void knh_StmtUUNIT_decl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int
 void knh_StmtUFUNC_decl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int level);
 void knh_StmtUMAPMAP_decl(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int level);
 void knh_StmtUALIAS(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns, int level);
-/* ../class/konohac/knh_Stmt_const.c */
-Term* knh_Stmt_const(Ctx *ctx, Stmt *b, knh_class_t reqc, NameSpace *ns);
 /* ../class/konohac/knh_Term.c */
 knh_type_t knh_Term_type(Term *tm);
 Token *knh_Term_firstToken(Term *tm);
@@ -1000,14 +1006,6 @@ knh_bytes_t knh_Token_tobytes(Token *o);
 void knh_Token__s(Ctx *ctx, Token *o, OutputStream *w, String *m);
 void knh_Token__k(Ctx *ctx, Token *o, OutputStream *w, String *m);
 void knh_Token__dump(Ctx *ctx, Token *o, OutputStream *w, String *m);
-/* ../class/konohac/knh_tokens_t.c */
-Token* knh_tokens_curToken(knh_tokens_t *tc);
-int knh_tokens_count(knh_tokens_t *tc, knh_token_t tt);
-void knh_tokens_nextStmt(knh_tokens_t *tc);
-knh_tokens_t knh_tokens_splitSTMT(Ctx *ctx, knh_tokens_t *tc);
-knh_tokens_t knh_tokens_splitEXPR(Ctx *ctx, knh_tokens_t *tc, knh_token_t tt);
-String *knh_tokens_toString(Ctx *ctx, knh_tokens_t *tc, char *premsg, char *postmsg);
-void knh_tokens_ignore(Ctx *ctx, knh_tokens_t *tc);
 /* ../class/konohac/knh_Token_const.c */
 Token* new_TokenCONST(Ctx *ctx, Any *fln, Any *data);
 void knh_Token_setCONST(Ctx *ctx, Token *o, Any *data);
@@ -1019,6 +1017,14 @@ void knh_Token_setLCONST(Ctx *ctx, Token *tk, NameSpace *ns);
 knh_bool_t knh_Token_isSystemVariable(Token *tk);
 void knh_Token_constSystemVariable(Ctx *ctx, Token *tk, Compiler *cpr);
 Token *knh_Token_const(Ctx *ctx, Token *o, knh_class_t reqc, NameSpace *ns);
+/* ../class/konohac/knh_tokens_t.c */
+Token* knh_tokens_curToken(knh_tokens_t *tc);
+int knh_tokens_count(knh_tokens_t *tc, knh_token_t tt);
+void knh_tokens_nextStmt(knh_tokens_t *tc);
+knh_tokens_t knh_tokens_splitSTMT(Ctx *ctx, knh_tokens_t *tc);
+knh_tokens_t knh_tokens_splitEXPR(Ctx *ctx, knh_tokens_t *tc, knh_token_t tt);
+String *knh_tokens_toString(Ctx *ctx, knh_tokens_t *tc, char *premsg, char *postmsg);
+void knh_tokens_ignore(Ctx *ctx, knh_tokens_t *tc);
 /* ../konoha/deps/cygwin/filesystem__cygwin.c */
 char * knh_format_ospath(char *buf, size_t bufsiz, knh_bytes_t path);
 char * knh_format_homepath(char *buf, size_t bufsiz);
@@ -1045,14 +1051,6 @@ void *ALT_dlopen(const char* path, int mode);
 void *ALT_dlsym(void* handle, const char* symbol);
 const char *ALT_dlerror();
 int ALT_dlclose(void* handle);
-/* ../konoha/knhapi/konoha_api.c */
-/* ../konoha/knhapi/konoha_libknh.c */
-/* ../konoha/knhapi/konoha_pkgapi.c */
-/* ../konoha/knhapi/konoha_shell.c */
-METHOD knh__Script_eval(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Script_isStatement(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Script_readline(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Script_addHistory(Ctx *ctx, knh_sfp_t *sfp);
 /* ../konoha/konoha.c */
 int main(int argc, char **argv);
 /* ../konoha/runtime/knh_tClass.c */
@@ -1084,7 +1082,7 @@ void knh_tContext_init0(void);
 knh_Context_t *new_Context0(Runtime *runtime, size_t stacksize);
 void knh_Context_traverse(Ctx *ctx, knh_Context_t *o, f_traverse ftr);
 void knh_tContext_traverse(Ctx* ctx, f_traverse f);
-/* ../konoha/runtime/knh_tException.c */
+/* ../konoha/runtime/knh_tExpt.c */
 void knh_tExpt_init0(void);
 void knh_tExpt_traverse(Ctx *ctx, f_traverse ftr);
 knh_class_t knh_tExpt_newId(Ctx *ctx);
@@ -1108,7 +1106,7 @@ Method *knh_tMethod_findMT(Ctx *ctx, knh_class_t cid, knh_methodn_t mn);
 /* ../konoha/runtime/knh_tName.c */
 int knh_bytes_isOptionalMT(knh_bytes_t t);
 knh_bytes_t knh_bytes_mtoption(knh_bytes_t t);
-char *knh_format_newFMT(char *buf, size_t bufsiz, knh_bytes_t t, int dot);
+char *knh_format_newFMT(char *buf, size_t bufsiz, knh_bytes_t t, int dot, char *fmt);
 void KNH_TFIELDN__T(Ctx *ctx, knh_fieldn_t fn, char *text);
 String *knh_tfieldn_name(knh_fieldn_t fn);
 knh_fieldn_t knh_tName_get_fnq(Ctx *ctx, knh_bytes_t tname, knh_fieldn_t def);
@@ -1150,6 +1148,7 @@ void knh_tStruct_init0(void);
 void knh_tStruct_traverse(Ctx *ctx, f_traverse f);
 knh_struct_t KNH_TSTRUCT(Ctx *ctx, 		knh_struct_t sid, size_t size, char *name, 		f_tStruct_init f0, f_tStruct_copy f1, /* f_tStruct_compare f2,*/ f_tStruct_traverse f3, 		f_hashCode f4, f_compareTo f5);
 char *knh_tstruct_name(knh_struct_t sid);
+/* ../konoha/runtime/konoha_api.c */
 /* ../konoha/runtime/konoha_call.c */
 void knh_stackf_locals(Ctx *ctx, size_t n);
 knh_vargc_t knh_sfp_argc(Ctx *ctx, knh_sfp_t *varg);
@@ -1161,12 +1160,23 @@ void knh_sfp_dump(Ctx *ctx, knh_sfp_t *sfp);
 /* ../konoha/runtime/konoha_ext.c */
 void knh_srand(knh_uint_t seed);
 knh_uint_t knh_rand();
+/* ../konoha/runtime/konoha_file.c */
+char * knh_format_parentpath(char *buf, size_t bufsiz, knh_bytes_t path, int n);
+char * knh_format_nzpath(char *buf, size_t bufsiz, knh_bytes_t path);
+char * knh_format_catpath(char *buf, size_t bufsiz, knh_bytes_t path, knh_bytes_t file);
+/* ../konoha/runtime/konoha_libknh.c */
 /* ../konoha/runtime/konoha_locale.c */
 char *konoha_encoding();
 char *knh_format_lang(char *buf, size_t bufsiz);
+/* ../konoha/runtime/konoha_pkgapi.c */
 /* ../konoha/runtime/konoha_print.c */
 void knh_sfp_print(Ctx *ctx, knh_sfp_t *sfp, knh_flag_t flag, Object *s, knh_methodn_t mn, Object *o);
 int knh_verbose(void);
+/* ../konoha/runtime/konoha_shell.c */
+METHOD knh__Script_eval(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__Script_isStatement(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__Script_readline(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__Script_addHistory(Ctx *ctx, knh_sfp_t *sfp);
 /* ../konoha/runtime/konoha_sync.c */
 void knh_Object_lock(Ctx *ctx, Object *o);
 void knh_Object_unlock(Ctx *ctx, Object *o);
@@ -1183,10 +1193,6 @@ METHOD knh__Object_opAs(Ctx *ctx, knh_sfp_t *sfp);
 Object* knh_Object_opAs(Ctx *ctx, Object *o, knh_class_t tcid);
 Object *knh_Object_opAs__type(Ctx *ctx, Object *o, knh_type_t reqt, Object *def);
 Exception* new_Exception__type(Ctx *ctx, Object *value, knh_type_t spec_type);
-/* ../konoha/utils/utils_file.c */
-char * knh_format_parentpath(char *buf, size_t bufsiz, knh_bytes_t path, int n);
-char * knh_format_nzpath(char *buf, size_t bufsiz, knh_bytes_t path);
-char * knh_format_catpath(char *buf, size_t bufsiz, knh_bytes_t path, knh_bytes_t file);
 
 #ifdef __cplusplus
 }
