@@ -56,6 +56,8 @@ extern "C" {
 
 #define METHOD             void  KNH_CC_FASTCALL
 
+#define KNH_USING_INT64 1
+
 /* ------------------------------------------------------------------------ */
 
 /* ------------------------------------------------------------------------ */
@@ -212,14 +214,15 @@ typedef unsigned long long int         knh_uint64_t;
 /* ------------------------------------------------------------------------ */
 
 #ifdef KNH_USING_INT64
+
 #define knh_integer_t    knh_int64_t
 #define knh_uinteger_t   knh_uint64_t
 
 #define KNH_INTEGER_MAX               LLONG_MAX
 #define KNH_INTEGER_MIN               LLONG_MIN
 #define KNH_INTEGER_FMT               "%lld"
-#define KNH_INTEGER_FMTX              "%llx"
-#define KNH_INTEGER_BSIZE             (sizeof(knh_int_t))
+#define KNH_INTEGER_XFMT              "%llx"
+#define KNH_INTEGER_BSIZE             (sizeof(knh_integer_t))
 #define KNH_INTEGER_FMTSIZ            40
 #define KNH_UINTEGER_MAX              ULLONG_MAX
 #define KNH_UINTEGER_MIN              0
@@ -233,8 +236,8 @@ typedef unsigned long long int         knh_uint64_t;
 #define KNH_INTEGER_MAX               LONG_MAX
 #define KNH_INTEGER_MIN               LONG_MIN
 #define KNH_INTEGER_FMT               "%ld"
-#define KNH_INTEGER_FMTX              "%lx"
-#define KNH_INTEGER_BSIZE             (sizeof(knh_int_t))
+#define KNH_INTEGER_XFMT              "%lx"
+#define KNH_INTEGER_BSIZE             (sizeof(knh_integer_t))
 #define KNH_INTEGER_FMTSIZ            40
 #define KNH_UINTEGER_MAX              ULONG_MAX
 #define KNH_UINTEGER_MIN              0
@@ -285,17 +288,21 @@ typedef knh_ushort_t          knh_methodn_t;
 
 #define KNH_OBJECT_MAGIC      578
 
+#ifdef KONOHA_WITH_RCGC
+#define KNH_HOBJECT_REFC      1
+#define KNH_HOBJECT_REFC_INIT 0
+#endif
+
 typedef struct knh_hObject_t {
 	knh_ushort_t magic;
 	knh_flag_t  flag;
 	knh_class_t bcid;
 	knh_class_t cid;
-#ifdef KONOHA_WITH_RCGC
-	knh_uint_t   refc;
+#ifdef KNH_HOBJECT_REFC
+	volatile knh_uint_t refc;
 #endif
 } knh_hObject_t ;
 
-
 typedef struct knh_Object_t {
 	knh_hObject_t h;
 	void *ref;
@@ -334,11 +341,6 @@ typedef struct knh_Object_t {
 
 /* ------------------------------------------------------------------------ */
 
-#define ARGi(o)            ((o).i)->value;
-#define ARGf(o)            ((o).f)->value;
-#define ARGc(o)            (knh_String_tochar((o).s))
-#define ARGs(o)            (knh_String_tochar((o).s))
-
 typedef struct knh_sfp_t {
 	union {
 		Object *o;
@@ -348,8 +350,9 @@ typedef struct knh_sfp_t {
 		struct knh_String_t *s;
 		struct knh_Bytes_t  *b;
 		struct knh_Method_t *mtd;
+		struct knh_Exception_t *e;
 		struct knh_ExceptionHandler_t *hdr;
-	} ;
+	};
 	knh_uint_t op;
 } knh_sfp_t;
 
@@ -418,13 +421,11 @@ typedef struct {
 	char                  *name;
 	f_tStruct_init         finit;
 	f_tStruct_traverse     ftraverse;
-//	f_tStruct_compare      fcompare;
 	f_tStruct_copy         fcopy;
 	f_hashCode             fhashCode;
 	f_compareTo            fcompareTo;
 } knh_tStruct_t ;
 
-
 /* ------------------------------------------------------------------------ */
 
 typedef int (*f_compare)(knh_Object_t *, knh_Object_t *);
@@ -446,10 +447,6 @@ typedef struct {
 	f_default                  fdefault;
 } knh_tClass_t;
 
-/* ------------------------------------------------------------------------ */
-
-
-
 /* ------------------------------------------------------------------------ */
 
 typedef knh_uint_t                knh_vargc_t;
@@ -514,14 +511,6 @@ typedef Object*    (*f_mapper)(Ctx *, Object *, struct knh_Mapper_t *);
 
 typedef knh_ushort_t             knh_line_t;
 
-//typedef knh_ushort_t             flpos_t;
-//
-//typedef struct {
-//	char    *fname;
-//	knh_line_t  fline;
-//	flpos_t  flpos;
-//} knh_filelog_t;
-
 /* ------------------------------------------------------------------------ */
 /* driver */
 /* ------------------------------------------------------------------------ */
@@ -533,8 +522,8 @@ typedef struct {
 	char *name;
 } knh_drvapi_t ;
 
-#define KNH_DRVAPI_TYPE__UNKNOWN 0
-#define KNH_DRVAPI_TYPE__BCONV   1
+#define KNH_DRVAPI_TYPE__UNKNOWN          0
+#define KNH_DRVAPI_TYPE__BCONV            1
 #define KNH_DRVAPI_TYPE__INPUTSTREAM      2
 #define KNH_DRVAPI_TYPE__OUTPUTSTREAM     3
 #define KNH_DRVAPI_TYPE__PARSER           4
@@ -547,15 +536,11 @@ typedef struct {
 /* mutex */
 /* ------------------------------------------------------------------------ */
 
-#ifndef KONOHA_MULTITHREAD
-	typedef knh_uint_t            knh_mutex_t;
+#ifdef KNH_USING_PTHREAD
+#define KNH_USING_THREAD 1
+#define knh_mutex_t  pthread_mutex_t
 #else
-	#if (KONOHA_MULTITHREAD == KONOHA_LIBPTHREAD)
-		typedef pthread_mutex_t    knh_mutex_t;
-	#else
-		#undef KONOHA_MULTITHREAD
-		typedef knh_uint_t         knh_mutex_t;
-	#endif
+#define knh_mutex_t  int  /* dummy */
 #endif
 
 /* ------------------------------------------------------------------------ */
