@@ -170,6 +170,7 @@ void knh_tObject_free(knh_Object_t *t)
 	int i;
 	for(i = 0; i < KNH_TOBJECT_SIZE; i++) {
 		if(t[i].h.magic == 0) continue;
+#ifdef KNH_HOBJECT_REFC
 		DBG_(
 		fprintf(stderr, "Memory Leak cid = %d,%s, refc=%d\n", (int)t[i].h.cid, STRUCTN(t[i].h.bcid), (int)t[i].h.refc);
 		{
@@ -183,6 +184,7 @@ void knh_tObject_free(knh_Object_t *t)
 			break;
 			}
 		} )
+#endif
 	}
 	KNH_FREE(t, SIZEOF_TOBJECT);
 	t = NULL;
@@ -221,7 +223,9 @@ knh_Object_t *new_PObject__NNctx(Ctx *ctx, knh_flag_t flag, knh_class_t bcid, kn
 		knh_statUsedObjectSize++;
 #endif
 		o->h.magic = KNH_OBJECT_MAGIC;
-		o->h.refc = 0;
+#ifdef KNH_HOBJECT_REFC
+		o->h.refc = KNH_HOBJECT_REFC_INIT;
+#endif
 		o->h.flag = flag;
 		o->h.bcid = bcid;
 		o->h.cid  = cid;
@@ -254,7 +258,9 @@ knh_Object_t *new_PObject0(Ctx *ctx, knh_flag_t flag, knh_class_t bcid, knh_clas
 			knh_statUsedObjectSize++;
 	#endif
 			o->h.magic = KNH_OBJECT_MAGIC;
-			o->h.refc = 0;
+#ifdef KNH_HOBJECT_REFC
+			o->h.refc = KNH_HOBJECT_REFC_INIT;
+#endif
 			o->h.flag = flag;
 			o->h.bcid = bcid;
 			o->h.cid  = cid;
@@ -321,7 +327,9 @@ knh_Object_t *new_ObjectX_malloc(Ctx *ctx, knh_flag_t flag, knh_class_t bcid, kn
 		knh_statUsedObjectSize++;
 #endif
 	o->h.magic = KNH_OBJECT_MAGIC;
-	o->h.refc = 0;
+#ifdef KNH_HOBJECT_REFC
+	o->h.refc = KNH_HOBJECT_REFC_INIT;
+#endif
 	o->h.flag = flag;
 	o->h.cid  = cid;
 	if(size > 0) {
@@ -362,7 +370,9 @@ Object *new_Object(Ctx *ctx, knh_flag_t flag, knh_class_t cid)
 #endif
 
 		o->h.magic = KNH_OBJECT_MAGIC;
-		o->h.refc = 0;
+#ifdef KNH_HOBJECT_REFC
+		o->h.refc = KNH_HOBJECT_REFC_INIT;
+#endif
 		o->h.flag = (knh_tClass[cid].oflag | flag);
 		o->h.cid  = cid;
 
@@ -493,7 +503,6 @@ void knh_Object_free(Ctx *ctx, knh_Object_t *o)
 
 	case CLASS_Boolean :  case CLASS_Class :
 	case CLASS_Int :   case CLASS_IntX :
-	case CLASS_Int64 : case CLASS_Int64X :
 	case CLASS_Float : case CLASS_FloatX :
 		break;
 
@@ -643,7 +652,6 @@ void knh_Object_traverse(Ctx *ctx, knh_Object_t *o, f_traverse ftr)
 
 	case CLASS_Boolean :  case CLASS_Class :
 	case CLASS_Int :   case CLASS_IntX :
-	case CLASS_Int64 : case CLASS_Int64X :
 	case CLASS_Float : case CLASS_FloatX :
 		break;
 
@@ -748,13 +756,6 @@ void knh_tString_init0(void);
 #define _knh_tMethodField(n)                 (MethodField*)knh_Array_n(DP(knh_rootSystem)->tMethodFields, n)
 #define _knh_tMethodField_size               knh_Array_size(DP(knh_rootSystem)->tMethodFields)
 
-///* ------------------------------------------------------------------------ */
-//
-//Any* ALT_NULL(void)
-//{
-//	return knh_constNull;
-//}
-
 /* ------------------------------------------------------------------------ */
 
 Object *new_Nue__T(Ctx *ctx, char *text)
@@ -790,11 +791,11 @@ knh_Int_t *new_Int0_(knh_int_t n)
 
 #define _new_Int(ctx, n)      new_Int__fast(ctx, CLASS_Int, (n))
 
-KNHAPI(Int*) new_Int__fast(Ctx *ctx, knh_class_t cid, knh_int_t value)
+KNHAPI(Int*) new_Int__fast(Ctx *ctx, knh_class_t cid, knh_integer_t value)
 {
 	KNH_ASSERT(ctx != NULL);
 	if(cid == CLASS_Int && KNH_TINT_MIN <= value && value <= KNH_TINT_MAX) {
-		return knh_tInt[value - KNH_TINT_MIN];
+		return knh_tInt[value - (KNH_TINT_MIN)];
 	}
 
 	if(ctx->unusedObject == NULL) {
@@ -818,7 +819,9 @@ KNHAPI(Int*) new_Int__fast(Ctx *ctx, knh_class_t cid, knh_int_t value)
 		knh_statUsedObjectSize++;
 #endif
 		o->h.magic = KNH_OBJECT_MAGIC;
-		o->h.refc = 0;
+#ifdef KNH_HOBJECT_REFC
+		o->h.refc = KNH_HOBJECT_REFC_INIT;
+#endif
 		o->h.flag = FLAG_Int;
 		o->h.bcid = CLASS_Int;
 		o->h.cid  = cid;
@@ -830,45 +833,6 @@ KNHAPI(Int*) new_Int__fast(Ctx *ctx, knh_class_t cid, knh_int_t value)
 
 /* ------------------------------------------------------------------------ */
 
-#define _new_Int64(ctx, n)      new_Int64__fast(ctx, CLASS_Int64, (n))
-
-KNHAPI(Int64*) new_Int64__fast(Ctx *ctx, knh_class_t cid, knh_int64_t value)
-{
-	KNH_ASSERT(ctx != NULL);
-	if(ctx->unusedObject == NULL) {
-		KNH_ASSERT(ctx->unusedObjectSize == 0);
-		((knh_Context_t*)ctx)->unusedObject = new_UnusedObject(ctx);
-		if(ctx->unusedObject == NULL) {
-			KNH_EXIT("Enlarge KNH_TOBJECTLIST_SIZE %d x %d",
-					KNH_TOBJECTLIST_SIZE, KNH_TOBJECT_SIZE);
-			return NULL;
-		}
-		else {
-			((knh_Context_t*)ctx)->unusedObjectSize += KNH_TOBJECT_SIZE;
-		}
-	}
-	{
-		knh_Object_t *o = ctx->unusedObject;
-		((knh_Context_t*)ctx)->unusedObject = (knh_Object_t*)o->ref;
-		((knh_Context_t*)ctx)->unusedObjectSize -= 1;
-
-#ifdef KNH_STATMODE1
-		knh_statUsedObjectSize++;
-#endif
-		o->h.magic = KNH_OBJECT_MAGIC;
-		o->h.refc = 0;
-		o->h.flag = FLAG_Int64;
-		o->h.bcid = CLASS_Int64;
-		o->h.cid  = cid;
-		knh_Int64_t *v = (knh_Int64_t*)o;
-		v->value = value;
-		v->ivalue = (knh_int_t)value;
-		return v;
-	}
-}
-
-/* ------------------------------------------------------------------------ */
-
 #define _new_Float(ctx, n)      new_Float__fast(ctx, CLASS_Float, (n))
 
 KNHAPI(Float*) new_Float__fast(Ctx *ctx, knh_class_t cid, knh_float_t value)
@@ -895,13 +859,14 @@ KNHAPI(Float*) new_Float__fast(Ctx *ctx, knh_class_t cid, knh_float_t value)
 		knh_statUsedObjectSize++;
 #endif
 		o->h.magic = KNH_OBJECT_MAGIC;
-		o->h.refc = 0;
+#ifdef KNH_HOBJECT_REFC
+		o->h.refc = KNH_HOBJECT_REFC_INIT;
+#endif
 		o->h.flag = FLAG_Float;
 		o->h.bcid = CLASS_Float;
 		o->h.cid  = cid;
 		knh_Float_t *v = (knh_Float_t*)o;
 		v->value = value;
-		v->ivalue = (knh_int_t)value;
 		return v;
 	}
 }
@@ -1082,6 +1047,7 @@ void knh_tObject_traverse(Ctx *ctx, f_traverse ftr)
 	ftr(ctx, (Object*)knh_constVoid);
 	ftr(ctx, (Object*)knh_constNull);
 
+	knh_tExpt_traverse(ctx, ftr);
 	knh_tClass_traverse(ctx, ftr);
 
 	if(IS_SWEEP(ftr)) {
