@@ -81,17 +81,6 @@ knh_drvapi_t *knh_System_getDRVAPI(Ctx *ctx, int type, knh_bytes_t name)
 	return p;
 }
 
-/* ------------------------------------------------------------------------ */
-
-KNHAPI(void) konoha_addParserDriver(Ctx *ctx, char *alias, knh_parser_drvapi_t *d)
-{
-	if(alias != NULL) {
-		KNH_TDRVAPI(ctx, alias, (knh_drvapi_t*)d);
-	}
-	else {
-		KNH_TDRVAPI(ctx, d->name, (knh_drvapi_t*)d);
-	}
-}
 
 /* ======================================================================== */
 /* [func] */
@@ -170,16 +159,15 @@ int knh_System_loadPackage(Ctx *ctx, knh_bytes_t pkgname)
 	char bufp[CLASSNAME_BUFSIZ], buff[FILENAME_BUFSIZ];
 	knh_format_bytes(bufp, sizeof(bufp), pkgname);
 #ifdef KONOHA_MONOLITHIC
-	knh_snprintf(buff, sizeof(buff), "knh%s_init", bufp);
-	f_libknh_init finit = (f_libknh_init)knh_DictSet_get__b(knh_funcDictSet, B(buff));
-	if(finit != NULL) {
+	knh_snprintf(buff, sizeof(buff), "knh%s_load", bufp);
+	f_pkgload fload = (f_pkgload)knh_DictSet_get__b(knh_funcDictSet, B(buff));
+	if(fload != NULL) {
 		NameSpace *pkgns = knh_System_getNameSpace(ctx, pkgname, 1);
 		DP(pkgns)->dlhdr = NULL;
 		NameSpace *curns = knh_Context_switchNameSpace(ctx, pkgns);
-		finit(ctx);
+		DP(pkgns)->pkgmeta = fload(ctx);
+		DP(pkgns)->pkgmeta->finit(ctx);
 		knh_Context_switchNameSpace(ctx, curns);
-		knh_snprintf(buff, sizeof(buff), "knh%s_traverse", bufp);
-		DP(pkgns)->ftraverse = (f_libknh_traverse)knh_DictSet_get__b(knh_funcDictSet, B(buff));
 		res = 1;
 	}
 	else {
@@ -193,14 +181,17 @@ int knh_System_loadPackage(Ctx *ctx, knh_bytes_t pkgname)
 	if (dlhdr != NULL) {
 		NameSpace *pkgns = knh_System_getNameSpace(ctx, pkgname, 1);
 		DP(pkgns)->dlhdr = dlhdr;
-		knh_snprintf(buff, sizeof(buff), "knh%s_init", bufp);
-		f_libknh_init finit = (f_libknh_init)knh_dlsym(dlhdr, buff);
-		if(finit != NULL) {
+		knh_snprintf(buff, sizeof(buff), "knh%s_load", bufp);
+		f_pkgload fload = (f_pkgload)knh_dlsym(dlhdr, buff);
+		if(fload != NULL) {
 			NameSpace *curns = knh_Context_switchNameSpace(ctx, pkgns);
-			finit(ctx);
+			DP(pkgns)->pkgmeta = fload(ctx);
+			if(KNH_CHECK_VERSION(DP(pkgns)->pkgmeta->buildid)) {
+				KNH_WARNING(ctx, "TOO OLD PACKAGE (buildid=%d)", DP(pkgns)->pkgmeta->buildid);
+				return 0;
+			}
+			DP(pkgns)->pkgmeta->finit(ctx);
 			knh_Context_switchNameSpace(ctx, curns);
-			knh_snprintf(buff, sizeof(buff), "knh%s_traverse", bufp);
-			DP(pkgns)->ftraverse = (f_libknh_traverse)knh_dlsym(dlhdr, buff);
 			res = 1;
 		}
 		else {
@@ -309,7 +300,7 @@ ClassSpec *knh_System_loadClassSpec(Ctx *ctx, knh_class_t bcid, knh_bytes_t urn)
 	DBG2_P("E urn='%s'", urn.buf);
 	KNH_SLOCK(LOCK_FUNC);
 	DBG2_P("finding.. '%s'", urn.buf);
-	f_makespec func = (void*)knh_DictSet_get__b(knh_makespecDictSet, urn);
+	f_makespec func = (f_makespec)knh_DictSet_get__b(knh_makespecDictSet, urn);
 	KNH_SUNLOCK(LOCK_FUNC);
 	if(func != NULL) {
 		return func(ctx, bcid, NULL);
